@@ -201,6 +201,32 @@ def _suggest_dependencies(requirements: str) -> List[str]:
     if any(word in req_lower for word in ["classify", "predict", "analyze", "nlp"]):
         deps.extend(["scikit-learn", "nltk", "spacy"])
     
+    # WebSocket/Real-time
+    if any(word in req_lower for word in ["websocket", "real-time", "streaming", "live"]):
+        deps.extend(["websockets", "asyncio"])
+    
+    # Authentication
+    if any(word in req_lower for word in ["oauth", "auth", "login", "token"]):
+        deps.extend(["authlib", "oauthlib"])
+    
+    # Social Media APIs
+    if "discord" in req_lower:
+        deps.append("discord.py")
+    if "slack" in req_lower:
+        deps.append("slack-sdk")
+    if "github" in req_lower:
+        deps.append("PyGithub")
+    
+    # Data Science/ML specific
+    if any(word in req_lower for word in ["numpy", "pandas", "matplotlib", "chart"]):
+        deps.extend(["numpy", "pandas", "matplotlib"])
+    if any(word in req_lower for word in ["machine learning", "ml", "prediction", "model"]):
+        deps.extend(["scikit-learn", "joblib"])
+    
+    # XML processing
+    if "xml" in req_lower:
+        deps.append("xmltodict")
+    
     return list(set(deps))  # Remove duplicates
 
 def _generate_tool_implementation(tool: Dict[str, Any]) -> str:
@@ -518,7 +544,7 @@ async def _generate_server_code(project_path: Path, plan: Dict[str, Any], ctx: C
 Generated by KEN-MCP on {datetime.now().strftime('%Y-%m-%d')}
 
 TODO: Claude, please customize this MCP server based on these requirements:
-{plan.get('original_requirements', 'No requirements provided')}
+{_escape_for_docstring(plan.get('original_requirements', 'No requirements provided'))}
 
 Instructions:
 1. Rename the placeholder tools to match the actual functionality needed
@@ -537,7 +563,7 @@ mcp = FastMCP(
     {plan.get('description', 'MCP server implementation')}
     
     Original Requirements:
-    {plan.get('original_requirements', 'No requirements provided')}
+    {_escape_for_docstring(plan.get('original_requirements', 'No requirements provided'))}
     
     TODO: Claude should update these instructions based on the actual implementation.
     """
@@ -677,6 +703,12 @@ if __name__ == "__main__":
         if "python-dotenv" not in dependencies:
             dependencies.append("python-dotenv")
     
+    # Add automatically detected dependencies
+    suggested_deps = _suggest_dependencies(plan.get('original_requirements', ''))
+    for dep in suggested_deps:
+        if dep not in dependencies:
+            dependencies.append(dep)
+    
     pyproject_content = f"""[project]
 name = "{project_path.name}"
 version = "0.1.0"
